cli/
====

`View code on Github <https://github.com/activist-org/ts-backend-check/tree/main/src/ts_backend_check/cli>`_

.. toctree::
    :maxdepth: 1

    main
    generate_config_file
    generate_test_project
    upgrade
    version
